@@ -22,13 +22,13 @@
 #' # Replication results model DEA1 in Tomkins and Green (1988)
 #' data("Departments")
 #' # Calculate Total income
-#' Departments$Total_income <- Departments[,5]+Departments[,6]+Departments[,7] 
+#' Departments$Total_income <- Departments[, 5] + Departments[, 6] + Departments[, 7] 
 #' data_DEA1 <- read_data(Departments,
-#'                        inputs=9,
-#'                        outputs=c(2,3,4,12))
+#'                        inputs = 9,
+#'                        outputs = c(2, 3, 4, 12))
 #' result <- model_basic(data_DEA1,
-#'                       orientation="io",
-#'                       rts="crs")
+#'                       orientation = "io",
+#'                       rts = "crs")
 #' efficiencies(result) # Table 3 (p.156) 
 #'  
 #' @export
@@ -50,6 +50,9 @@ efficiencies.dea <-
     } else if ("beta" %in% names(deasol$DMU[[1]])) {
       eff <- unlist(lapply(deasol$DMU, function(x)
         x$beta))
+    } else if ("gamma" %in% names(deasol$DMU[[1]])) {
+      eff <- unlist(lapply(deasol$DMU, function(x)
+        x$gamma))
     } else if ("delta" %in% names(deasol$DMU[[1]])) {
       eff <- unlist(lapply(deasol$DMU, function(x)
         x$delta))
